Crate recall_ipc_types

Crate recall_ipc_types 

Re-exports

pub use self::actor_error::*;

Modules

actor_error
codes

Macros

actor_error
Convenience macro for generating Actor Errors
tcid_ops
Assuming that the type implements maybe_load and flush, implement some convenience methods.

Structs

Actor
BLS
EthAddress
A Filecoin address as represented in the FEVM runtime (also called EVM-form).
ID
Secp256k1
TAddress
TAddressKey
Apparently CBOR has problems using Address as a key in HashMap. This type can be used to wrap an address and turn it into String for the purpose of CBOR serialization.
TAmt
Static typing information for AMT fields, a.k.a. Array.
TCid
TCid is typed content, represented by a Cid.
THamt
Static typing information for HAMT fields, a.k.a. Map.
TLink
Static typing information for Cid fields to help read and write data safely.

Constants

HAMT_BIT_WIDTH

Traits

CodeType
Helper type to be able to define Code as a generic parameter.
TCidContent
Marker trait for types that were meant to be used inside a TCid.

Functions

make_empty_map
Create a hamt with a custom bitwidth.
make_map_with_root
Create a map with a root cid.
make_map_with_root_and_bitwidth
Create a map with a root cid.

Type Aliases

Array
Array type used within actors. The underlying type is an AMT.
Map
Map type to be used within actors. The underlying type is a HAMT.